@@ -1,7 +1,7 @@
 import os
 import streamlit.components.v1 as components
 
-_RELEASE = False
+_RELEASE = True
 
 if not _RELEASE:
     _component_func = components.declare_component(
@@ -35,12 +35,11 @@ def click_detector(html_content, key=None):
 if not _RELEASE:
     import streamlit as st
 
-    clicked = click_detector(
-        """<p><a href='#' id='Link 1'>First link</a></p>
+    content1 = """<p><a href='#' id='Link 1'>First link</a></p>
         <p><a href='#' id='Link 2'>Second link</a></p>
         <a href='#' id='Image 1'><img width='20%' src='https://images.unsplash.com/photo-1565130838609-c3a86655db61?w=200'></a>
         <a href='#' id='Image 2'><img width='20%' src='https://images.unsplash.com/photo-1565372195458-9de0b320ef04?w=200'></a>
         """
-    )
+    clicked = click_detector(content1)
 
     st.markdown(f"**{clicked} clicked**" if clicked != "" else "**No click**")
